fn datatype_from_scopes(scopes: Scopes) -> DatatypeExpand description
Return the datatype that best matches scopes, or Datatype::Unknown if there is no match.
Nearly every scope type has a matching datatype, but there are far more datatypes than scope types.
Note that only Scopes values that are narrowed down to a single scope type can be matched.