pub fn scope_from_datatype(dtype: Datatype) -> Option<Scopes>Expand description
Return the scope type that best matches dtype, or None if there is no match.
Nearly every scope type has a matching datatype, but there are far more datatypes than scope types.