fn validate_argument(
arg: &CodeArg,
data: &Everything,
sc: &mut ScopeContext,
dc: &DataContext,
expect_arg: Arg,
lang: Option<Language>,
format: Option<&Token>,
)Expand description
Internal function for validating an argument to a datatype code.
If the argument is iself a code chain, this will end up calling validate_datatypes recursively.
arg: The actual argument being supplied.sc: The available named scopes.expect_arg: The form of argument expected by the promote or function.lang: The language of the localization file in which this code appears. This is just passed through.format: The formatting code for this code chain. This just passed through.